@@ -1,3 +1,4 @@
+import os
 import subprocess
 import logging
 import dateutil.parser
@@ -20,7 +21,7 @@ class CommonClient(object):
 
     def run_command(self, subcommand, args, success_code=0, 
                     return_stderr=False, combine=False, return_binary=False):
-        cmd = ['svn', subcommand] + args
+        cmd = ['svn', '--non-interactive', subcommand] + args
 
         _logger.debug("RUN: %s" % (cmd,))
 
@@ -138,7 +139,7 @@ class CommonClient(object):
                 return_binary=True)
 
     def log_default(self, timestamp_from_dt=None, timestamp_to_dt=None, 
-                    limit=None):
+                    limit=None, rel_filepath=''):
         """Allow for the most-likely kind of log listing: the complete list, a 
         FROM and TO timestamp, a FROM timestamp only, or a quantity limit.
         """
@@ -168,7 +169,7 @@ class CommonClient(object):
 
         result = self.run_command(
                     'log', 
-                    args + ['--xml', self.__url_or_path], 
+                    args + ['--xml', os.path.join(self.__url_or_path, rel_filepath)], 
                     combine=True)
 
         root = xml.etree.ElementTree.fromstring(result)
@@ -177,7 +178,7 @@ class CommonClient(object):
                 ['date', 'msg', 'revision', 'author'])
         
         for e in root.findall('logentry'):
-            entry_info = dict([(x.tag, x.text) for x in e.getchildren()])
+            entry_info = {x.tag: x.text for x in e.getchildren()}
 
             yield c(
                 msg=entry_info['msg'],
